@@ -22,6 +22,7 @@ Choice::Choice(QObject *parent) :
     Target = 0;
     Text = "";
     Random = false;
+    ShowWithEnemies = false;
     MinValue = 0;
     MaxValue = 0;
     m_Abort = false;
@@ -131,6 +132,29 @@ bool Section::RemoveItem(QString name)
     return false;
 }
 
+
+Item* Section::AddItem(QString name, bool special)
+{
+    if (!name.isEmpty()){
+        Item* i = new Item(this);
+        i->Name = name;
+        i->SetIsSpecial(special);
+        Items.append(i);
+        return i;
+    }
+    return NULL;
+}
+
+void Section::CopyItemsToSection(int section)
+{
+    Book* book = GetBook();
+    if (book){
+        Section* s = book->GetSection(section);
+        if (s)
+            s->Items = Items;
+    }
+}
+
 Book::Book(QObject *parent) :
     QObject(parent)
 {
@@ -156,6 +180,13 @@ int Book::GetSerie()
     return Book::Unknown;
 }
 
+Section* Book::GetSection(int section)
+{
+    if(Sections.contains(section))
+        return Sections[section];
+    return NULL;
+}
+
 bool Book::Load(QString filename, bool full)
 {
     QFile file(filename);
@@ -252,6 +283,31 @@ QString Book::AddGenericFunctions(QString functions)
                        }, \
                        use_CombatskillDelta: function()  { \
                            Player.SetTempCombatSkillDelta(Item.GetCombatskillDelta()); \
+                           Player.SetTemporaryCombatSkillItem(Item.GetName()); \
+                       }, \
+                       use_Adgana: function()  { \
+                           var used = parseInt(Player.GetProperty('Adgana_used')); \
+                           if (isNaN(used)) \
+                               used = 0; \
+                           if (used > 0) \
+                             Player.SetTempCombatSkillDelta(3); \
+                           else \
+                             Player.SetTempCombatSkillDelta(6); \
+                           Player.SetTemporaryCombatSkillItem(Item.GetName()); \
+                           Player.SetProperty('Adgana_used', used + 1); \
+                       }, \
+                       endeffect_Adgana: function()  { \
+                           Window.DisableChoiceButtons(); \
+                           var used = parseInt(Player.GetProperty('Adgana_used')); \
+                           if (isNaN(used)) \
+                               used = 0; \
+                           var rnd = Window.GetRandomNumber(); \
+                           if (used == 0 && rnd <= 1 || used > 0 && rnd <= 3){ \
+                               Window.MessageBox('Info', 'You have become addicted to Adgana'); \
+                               Player.SetBaseEnduranceNoBonus(Player.GetBaseEnduranceNoBonus() - 4); \
+                               Player.SetProperty('Adgana_Addicted', 'true'); \
+                           } \
+                           Window.EnableChoiceButtons(); \
                        },";
     if (!res.isEmpty() && res.startsWith("({")){
         res.insert(2, generic);
@@ -271,6 +327,7 @@ Choice* Book::ParseChoice(Section* section, QXmlStreamReader* reader)
     c->Target = attrs.value("target").toString().toInt();
     c->MinValue = attrs.value("minvalue").toString().toInt();
     c->MaxValue = attrs.value("maxvalue").toString().toInt();
+    c->ShowWithEnemies = attrs.value("showwithenemies").toString().toInt() == 1;
 
     while(!reader->atEnd() &&
           !reader->hasError()) {
@@ -340,6 +397,8 @@ Weapon* Book::ParseWeapon(Section* section, QXmlStreamReader* reader)
     w->SetCombatskillDelta(attrs.value("combatskilldelta").toString().toInt());
     w->SetRandomBonus(attrs.value("randombonus").toString().toInt());
 
+    if (attrs.hasAttribute("hands"))
+        w->SetHands(attrs.value("hands").toString().toInt());
     QString tclass = attrs.value("class").toString();
     QStringList ele = tclass.split(";");
     foreach(QString wclass, ele){
@@ -370,10 +429,18 @@ Item* Book::ParseItem(Section* section, QXmlStreamReader* reader)
         i->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     i->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
     i->SetIsMeal(attrs.value("ismeal").toString().toInt() == 1);
+    i->SetIsArmor(attrs.value("isarmor").toString().toInt() == 1);
+    if (attrs.hasAttribute("armorclass")){
+        i->SetArmorClass(attrs.value("armorclass").toString());
+        if (i->GetArmorClass() == Armor::Shield)
+            i->SetHands(1);
+    }
     i->SetIsArrow(attrs.value("isarrow").toString().toInt() == 1);
     if (attrs.hasAttribute("quantity"))
         i->SetQuantity(attrs.value("quantity").toString().toInt());
     i->SetIsBackpack(attrs.value("isbackpack").toString().toInt() == 1);
+    i->SetIsQuiver(attrs.value("isquiver").toString().toInt() == 1);
+    i->SetArrows(attrs.value("arrows").toString().toInt());
     i->SetCombatskillDelta(attrs.value("combatskilldelta").toString().toInt());
     i->SetRandomBonus(attrs.value("randombonus").toString().toInt());
     i->SetEnduranceDelta(attrs.value("endurancedelta").toString().toInt());
@@ -410,6 +477,8 @@ ShopItem* Book::ParseShopItem(Section* section, QXmlStreamReader* reader)
     if (attrs.hasAttribute("quantity"))
         i->SetQuantity(attrs.value("quantity").toString().toInt());
     i->SetIsBackpack(attrs.value("isbackpack").toString().toInt() == 1);
+    i->SetIsQuiver(attrs.value("isquiver").toString().toInt() == 1);
+    i->SetArrows(attrs.value("arrows").toString().toInt());
     i->SetCombatskillDelta(attrs.value("combatskilldelta").toString().toInt());
     i->SetRandomBonus(attrs.value("randombonus").toString().toInt());
     i->SetEnduranceDelta(attrs.value("endurancedelta").toString().toInt());
@@ -424,6 +493,9 @@ ShopItem* Book::ParseShopItem(Section* section, QXmlStreamReader* reader)
 
     i->Price = attrs.value("price").toString().toInt();
     i->SellPrice = attrs.value("sellprice").toString().toInt();
+
+    if (attrs.hasAttribute("hands"))
+        i->SetHands(attrs.value("hands").toString().toInt());
     int iclass = Weapon::GetClass(attrs.value("weaponclass").toString());
     if (iclass != Weapon::None){
         i->AddClass(iclass);
