@@ -1,6 +1,7 @@
 #include "item.h"
 #include <QStringList>
 #include <QMessageBox>
+#include <QUuid>
 
 PropertiesItem::PropertiesItem(QObject *parent) :
     QObject(parent)
@@ -32,6 +33,7 @@ void PropertiesItem::SetProperty(QString name, QString value)
 Item::Item(QObject *parent) :
     PropertiesItem(parent)
 {
+    SetUUID(QUuid::createUuid().toString());
     Name = "";
     Description = "";
     SetQuantity(1);
@@ -54,7 +56,25 @@ QString Item::GetDescription()
         return QString("Contains %1 arrows").arg(GetArrows());
 
     if (GetEnduranceRestore() > 0)
-        return QString("Restores %1 ENDURANCE POINTS").arg(GetEnduranceRestore());
+#ifdef Q_WS_MAEMO_5
+        return QString("Restores %1 END. points").arg(GetEnduranceRestore());
+#else
+        return QString("Restores %1 ENDURANCE points").arg(GetEnduranceRestore());
+#endif
+
+    if (GetEnduranceDelta() > 0)
+#ifdef Q_WS_MAEMO_5
+        return QString("Adds %1 END. points to your total").arg(GetEnduranceDelta());
+#else
+        return QString("Adds %1 ENDURANCE points to your total").arg(GetEnduranceDelta());
+#endif
+
+    if (GetCombatskillDelta() > 0){
+        if (GetCanBeEquipped())
+            return QString("Adds %1 points to your COMBAT SKILL when used in combat").arg(GetCombatskillDelta());
+        else
+            return QString("Increase your COMBAT SKILL by %1 points for the duration of a fight").arg(GetCombatskillDelta());
+    }
 
     return "";
 }
@@ -102,6 +122,12 @@ void Item::SetCanBeEquipped(bool value)
     SetBoolProperty("CanBeEquipped", value);
 }
 
+void Item::SetArmorClass(QString value)
+{
+    int aClass = Armor::GetClass(value);
+    SetProperty("ArmorClass", QString::number(aClass));
+}
+
 Weapon::Weapon(QObject *parent) :
     Item(parent)
 {
@@ -123,7 +149,7 @@ int Weapon::GetClass(QString wclass)
         return Weapon::Spear;
     else if (!QString::compare(wclass, "Mace", Qt::CaseInsensitive))
         return Weapon::Mace;
-    else if (!QString::compare(wclass, "ShortSword", Qt::CaseInsensitive))
+    else if (!QString::compare(wclass, "ShortSword", Qt::CaseInsensitive) || !QString::compare(wclass, "Short Sword", Qt::CaseInsensitive))
         return Weapon::ShortSword;
     else if (!QString::compare(wclass, "Warhammer", Qt::CaseInsensitive))
         return Weapon::WarHammer;
@@ -140,6 +166,15 @@ int Weapon::GetClass(QString wclass)
     return Weapon::None;
 }
 
+int Weapon::GetHands()
+{
+    QList<int> classes = Classes();
+    if (classes.contains(Spear) || classes.contains(Broadsword) ||
+        classes.contains(Quarterstaff))
+        return 2;
+    return 1;
+}
+
 void Weapon::AddClass(int iClass)
 {
     QString str = GetProperty("Classes");
@@ -225,6 +260,8 @@ int Armor::GetClass(QString sClass)
         return Armor::Body;
     else if (!QString::compare(sClass, "Hand", Qt::CaseInsensitive))
         return Armor::Hand;
+    else if (!QString::compare(sClass, "Shield", Qt::CaseInsensitive))
+        return Armor::Shield;
     return Armor::None;
 }
 
@@ -237,3 +274,10 @@ int Armor::GetClass()
 {
     return GetArmorClass();
 }
+
+int Armor::GetHands()
+{
+    if (GetClass() == Armor::Shield)
+        return 1;
+    return 0;
+}
