@@ -46,7 +46,7 @@ QList<Item*> Player::BackpackItems()
 {
     QList<Item*> res;
     foreach (Item* i, Items){
-        if (!i->GetIsWeapon() && !i->GetIsSpecial())
+        if (i->GetIsBackpackItem())
             res.append(i);
     }
     return res;
@@ -72,6 +72,13 @@ QString Player::GetRankDescription(int serie, int kaiDisciplinesCount)
                                          << "Primate" << "Tutelary" << "Principalin" << "Mentora"
                                          << "Scion-kai" << "Archmaster" << "Kai Grand Master";
 
+    QStringList grandMaster = QStringList() << "Kai Grand Master Senior" << "Kai Grand Master Superior"
+                                            << "Kai Grand Sentinel" << "Kai Grand Defender"
+                                            << "Kai Grand Guardian" << "Sun Knight" << "Sun Lord"
+                                            << "Sun Thane" << "Grand Thane" << "Grand Crown" << "Sun Prince"
+                                            << "Kai Supreme Master";
+
+
     switch (serie){
     case Book::Kai:
         return kai.at(kaiDisciplinesCount - 1);
@@ -80,10 +87,10 @@ QString Player::GetRankDescription(int serie, int kaiDisciplinesCount)
         return magnakai.at(kaiDisciplinesCount - 1);
         break;
     case Book::GrandMaster:
-        return "";
+        return grandMaster.at(kaiDisciplinesCount - 1);
         break;
     case Book::NewOrder:
-        return "";
+        return grandMaster.at(kaiDisciplinesCount - 4);
         break;
     }
 
@@ -107,96 +114,74 @@ bool Player::IsDead()
 
 int Player::GetCombatSkill()
 {
-    int result = BaseCombatSkill + TemporaryCombatSkillDelta;
-    foreach (Item* i, Items){
-        if (i->GetIsEquipped())
-            result += i->GetCombatskillDelta();
-    }
-
-    foreach (KaiDiscipline* d, KaiDisciplines){
-        if (d->Active){
-            result += d->CombatSkillDelta;
-
-            Weaponskill* ws = qobject_cast<Weaponskill*>(d);
-            if (ws){
-                foreach(Item* i, Items){
-                    if (i->GetIsWeapon()){
-                        Weapon* w = (Weapon*)i;
-                        if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon)){
-                            result += 2;
-                            break;
-                        }
-                    }
-                }
-            }
-
-            Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
-            if (wm){
-                bool done = false;
-                foreach(Item* i, Items){
-                    if (i->GetIsWeapon()){
-                        Weapon* w = (Weapon*)i;
-                        if (w->GetIsEquipped()){
-                            foreach (int wc, w->Classes()){
-                                if (wm->Weapons.contains(wc)){
-                                    result += 3;
-                                    done = true;
-                                    break;
-                                }
-                            }
-
-                        }
-                    }
-                    if (done)
-                        break;
-                }
-            }
-
-        }else{
-            //Special case: Psi-surge when deactivate acts like Mindblast
-            PsiSurge* ps = qobject_cast<PsiSurge*>(d);
-            if (ps)
-                result += 2;
-        }
-    }
-
-    foreach (LoreCircle* lc, LoreCircles::Circles){
-        if (lc->Check(this))
-            result += lc->CombatSkillBonus;
-    }
-
-    if (GetEquippedWeapon() == NULL)
-        result -= 4;
-
-    return result;
+    return GetCombatSkill(NULL);
 }
 
 int Player::GetCombatSkill(Enemy* enemy)
 {
+    return GetCombatSkill(enemy, NULL);
+}
+
+QStringList Player::GetCombatSkillDescription(Enemy* enemy)
+{
+    QStringList res;
+    GetCombatSkill(enemy, &res);
+    return res;
+}
+
+int Player::GetCombatSkill(Enemy* enemy, QStringList* description)
+{
+    if (description){
+        description->append(QString("Base|%1").arg(BaseCombatSkill));
+        if (TemporaryCombatSkillDelta > 0)
+            description->append(QString("Temporary bonus|+%1").arg(TemporaryCombatSkillDelta));
+    }
+
     int result = BaseCombatSkill + TemporaryCombatSkillDelta;
+
     foreach (Item* i, Items){
-        if (i->GetIsEquipped())
+        if (i->GetIsEquipped()){
             result += i->GetCombatskillDelta();
+            if (description && i->GetCombatskillDelta())
+                description->append(QString("%1|+%2").arg(i->Name)
+                                                          .arg(i->GetCombatskillDelta()));
+
+        }
     }
 
     foreach (KaiDiscipline* d, KaiDisciplines){
         if (d->Active){
-            if (!enemy->DisciplineImmunities.contains(d->Name))
+            // Count CombatSkillDelta only versus enemies:
+            if (enemy != NULL && !enemy->DisciplineImmunities.contains(d->Name)){
                 result += d->CombatSkillDelta;
+                if (description && d->CombatSkillDelta > 0)
+                    description->append(QString("%1|+%2").arg(d->Name).arg(d->CombatSkillDelta));
+            }
 
+            // Weaponskill
             Weaponskill* ws = qobject_cast<Weaponskill*>(d);
             if (ws){
+                KaiDiscipline* td = GetDiscipline("Weaponmastery");
+                Weaponmastery* wm = td != NULL ? qobject_cast<Weaponmastery*>(td) : NULL;
+                bool done = false;
                 foreach(Item* i, Items){
                     if (i->GetIsWeapon()){
                         Weapon* w = (Weapon*)i;
-                        if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon)){
+                        if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon) &&
+                            (!wm || !wm->Weapons.contains(ws->Weapon))){
                             result += 2;
+                            done = true;
+                            if (description)
+                                description->append(QString("%1|+2").arg(ws->Description()));
                             break;
                         }
                     }
+                    if (done)
+                        break;
                 }
             }
 
+            // Weaponmastery
             Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
             if (wm){
                 bool done = false;
@@ -206,8 +191,15 @@ int Player::GetCombatSkill(Enemy* enemy)
                         if (w->GetIsEquipped()){
                             foreach (int wc, w->Classes()){
                                 if (wm->Weapons.contains(wc)){
-                                    result += 3;
+                                    int delta = 3;
+                                    if (GetDisciplineCount() >= 8)
+                                        delta = 4;
+                                    result += delta;
                                     done = true;
+                                    if (description)
+                                        description->append(QString("%1 in %2|+%3").arg(wm->Description())
+                                                                                    .arg(Weapon::ClassDescription(wc))
+                                                                                    .arg(delta));
                                     break;
                                 }
                             }
@@ -218,37 +210,72 @@ int Player::GetCombatSkill(Enemy* enemy)
                         break;
                 }
             }
-        }else{
-            //Special case: Psi-surge when deactivate acts like Mindblast
-            if (!enemy->DisciplineImmunities.contains("Mindblast")){
-                PsiSurge* ps = qobject_cast<PsiSurge*>(d);
-                if (ps)
-                    result += 2;
-            }
         }
     }
 
-    if (GetEquippedWeapon() == NULL)
-        result -= 4;
+    foreach (LoreCircle* lc, LoreCircles::Circles){
+        if (lc->Check(this)){
+            result += lc->CombatSkillBonus;
+            if (description && lc->CombatSkillBonus > 0)
+                description->append(QString("Lore-circle of %1|+%2").arg(lc->Name()).arg(lc->CombatSkillBonus));
+        }
+    }
+
+    if (GetEquippedWeapon() == NULL){
+        int delta = 4;
+        if (GetSerie() == Book::Magnakai){
+            if (GetDisciplineCount() >= 5)
+                delta = 2;
+            else if (GetDisciplineCount() >= 8)
+                delta = 1;
+        }
+
+        result -= delta;
+        if (description)
+            description->append(QString("No weapon equipped|-%1").arg(delta));
+    }
 
     return result;
 }
 
-int Player::GetBaseEndurance()
+int Player::GetBaseEndurance(QStringList* description)
 {
+    if (description)
+        description->append(QString("Base|%1").arg(BaseEndurance));
+
     int result = BaseEndurance;
     foreach (Item* i, Items){
-        if (i->GetIsEquipped())
+        if (i->GetIsEquipped()){
             result += i->GetEnduranceDelta();
+            if (description && i->GetEnduranceDelta())
+                description->append(QString("%1|+%2").arg(i->Name)
+                                                          .arg(i->GetEnduranceDelta()));
+
+        }
     }
 
     foreach (LoreCircle* lc, LoreCircles::Circles){
-        if (lc->Check(this))
+        if (lc->Check(this)){
             result += lc->EnduranceBonus;
+            if (description && lc->EnduranceBonus > 0)
+                description->append(QString("Lore-circle of %1|+%2").arg(lc->Name()).arg(lc->EnduranceBonus));
+        }
     }
     return result;
 }
 
+QStringList Player::GetBaseEnduranceDescription()
+{
+    QStringList res;
+    GetBaseEndurance(&res);
+    return res;
+}
+
+int Player::GetBaseEndurance()
+{
+    return GetBaseEndurance(NULL);
+}
+
 void Player::RemoveDiscipline(QString name)
 {
     KaiDiscipline* remove = NULL;
@@ -264,14 +291,23 @@ void Player::RemoveDiscipline(QString name)
 
 void Player::RemoveDisciplines()
 {
-    foreach (KaiDiscipline* d, KaiDisciplines)
+    /*foreach (KaiDiscipline* d, KaiDisciplines)
         delete d;
-    KaiDisciplines.clear();
+    KaiDisciplines.clear();*/
+
+    // Reset the discipline's serie to avoid counting them with GetDisciplineCount
+    foreach (KaiDiscipline* d, KaiDisciplines)
+        d->Serie = 0;
 }
 
 int Player::GetDisciplineCount()
 {
-    return KaiDisciplines.count();
+    int res = 0;
+    foreach (KaiDiscipline* d, KaiDisciplines){
+        if (d->Serie != 0)
+            res++;
+    }
+    return res;
 }
 
 KaiDiscipline* Player::GetDiscipline(QString name)
@@ -292,6 +328,14 @@ bool Player::HasDiscipline(QString name)
     return false;
 }
 
+bool Player::IsDisciplineActive(QString name)
+{
+    KaiDiscipline* d = GetDiscipline(name);
+    if (d != NULL)
+        return d->Active;
+    return false;
+}
+
 bool Player::HasWeaponskillIn(QString className)
 {
     foreach (KaiDiscipline* d, KaiDisciplines){
@@ -627,7 +671,7 @@ void Player::SetHasBackpack(bool value)
     if (!m_Backpack){
         QList<Item*> toRemove;
         foreach (Item* i, Items){
-            if (!i->GetIsSpecial())
+            if (i->GetIsBackpackItem())
                 toRemove.append(i);
         }
 
@@ -656,7 +700,7 @@ int Player::GetBackpackFreeSpace()
 
     int size = 0;
     foreach(Item* i, Items){
-        if (!i->GetIsSpecial())
+        if (i->GetIsBackpackItem())
             size += i->GetSize();
     }
     return 8 - size;
@@ -685,6 +729,24 @@ Weapon* Player::GetEquippedWeapon()
     return NULL;
 }
 
+QList<Armor*> Player::GetEquippedArmors()
+{
+    QList<Armor*> res;
+    foreach (Item* i, Items){
+        if (i->GetIsArmor() && i->GetIsEquipped())
+            res.append((Armor*)i);
+    }
+    return res;
+}
+
+QStringList Player::GetAllItems()
+{
+    QStringList res;
+    foreach (Item* i, Items)
+        res.append(i->Name);
+    return res;
+}
+
 QStringList Player::GetSpecialItems()
 {
     QStringList res;
@@ -699,7 +761,17 @@ QStringList Player::GetItems()
 {
     QStringList res;
     foreach (Item* i, Items){
-        if (!i->GetIsSpecial() && !i->GetIsWeapon())
+        if (i->GetIsBackpackItem())
+            res.append(i->Name);
+    }
+    return res;
+}
+
+QStringList Player::GetMeals()
+{
+    QStringList res;
+    foreach (Item* i, Items){
+        if (i->GetIsMeal())
             res.append(i->Name);
     }
     return res;
@@ -758,12 +830,61 @@ void Player::Equip(QString name)
     }
 }
 
+bool Player::GetCanUseShield()
+{
+    if (HasProperty("CanUseShield"))
+        return GetBoolProperty("CanUseShield");
+    return true;
+}
+
+void Player::SetCanUseShield(bool value)
+{
+    SetBoolProperty("CanUseShield", value);
+    QList<Armor*> equipped = GetEquippedArmors();
+    foreach (Armor* a, equipped){
+        if (a->GetArmorClass() == Armor::Shield)
+            a->Unequip();
+    }
+}
+
+int Player::GetHands()
+{
+    if (HasProperty("Hands"))
+        return GetProperty("Hands").toInt();
+    return 2;
+}
+
+void Player::SetHands(int value)
+{
+    SetProperty("Hands", QString::number(value));
+    if (GetFreeHands() < 0){
+        QList<Armor*> equipped = GetEquippedArmors();
+        foreach (Armor* a, equipped){
+            if (a->GetArmorClass() == Armor::Shield)
+                a->Unequip();
+        }
+
+        if (GetFreeHands() < 0){
+            Weapon* w = GetEquippedWeapon();
+            if (w != NULL)
+                w->Unequip();
+        }
+    }
+}
+
 int Player::GetFreeHands()
 {
-    int res = 2;
+    int res = GetHands();
     foreach(Item* i, Items){
-        if (i->GetIsEquipped())
-            res -= i->GetHands();
+        if (i->GetIsEquipped()){
+            Weapon* w = qobject_cast<Weapon*>(i);
+            if (w)
+                res -= w->GetHands();
+            else if (i->GetIsArmor() && i->GetArmorClass() == Armor::Shield)
+                res -= 1;
+            else
+                res -= i->GetHands();
+        }
     }
     return res;
 }
@@ -840,13 +961,31 @@ bool Player::HasQuiver()
     return false;
 }
 
+int Player::GetThrowBonus()
+{
+    int bonus = 0;
+    // When using a Bow or thrown Weapon and instructed to pick a number from the
+    // Random Number Table, add 2 to the number picked if you are a Mentora
+    // with the Magnakai Discipline of Weaponmastery.
+    if (HasDiscipline("Weaponmastery") && GetDisciplineCount() >= 7)
+        bonus += 2;
+
+    return bonus;
+}
+
 int Player::GetBowBonus(bool includeDisciplines)
 {
     int bonus = 0;
     if (includeDisciplines){
         if (HasWeaponmasteryIn("Bow"))
             bonus += 3;
+        // When using a Bow or thrown Weapon and instructed to pick a number from the
+        // Random Number Table, add 2 to the number picked if you are a Mentora
+        // with the Magnakai Discipline of Weaponmastery.
+        if (HasDiscipline("Weaponmastery") && GetDisciplineCount() >= 7)
+            bonus += 2;
     }
+
     foreach (Weapon* w, Weapons()){
         if (w->Classes().contains(Weapon::Bow))
             bonus += w->GetRandomBonus();
@@ -855,10 +994,37 @@ int Player::GetBowBonus(bool includeDisciplines)
     return bonus;
 }
 
+int Player::GetSerie()
+{
+    int max = Book::Unknown;
+    foreach (KaiDiscipline* d, KaiDisciplines){
+        if (d->Serie > max)
+            max = d->Serie;
+    }
+    return max;
+}
+
+void Player::AppendNotesLine(QString value)
+{
+    QString notes = GetNotes();
+    if (notes.length())
+        notes.append("\n");
+    notes.append(value);
+    SetNotes(value);
+}
+
 void Player::Dump()
 {
+    qDebug() << "Base properties:";
+    qDebug() << "  Endurance        :" << GetEndurance();
+    qDebug() << "  Base Combat Skill:" << GetBaseCombatSkill();
+    qDebug() << "  Combat Skill     :" << GetCombatSkill();
     qDebug() << "Properties:";
     foreach(QString key, Properties.keys()){
-        qDebug() << key << ":" << Properties[key];
+        qDebug() << "  " << key << ":" << Properties[key];
+    }
+    qDebug() << "Items:";
+    foreach(Item* i, Items){
+        qDebug() << "  " << i->GetUUID() << i->GetName() << "Special:" << i->GetIsSpecial();
     }
 }
