@@ -4,7 +4,7 @@
 #include <QCloseEvent>
 
 CartwheelWindow::CartwheelWindow(QWidget *parent, Player* player) :
-    QMainWindow(parent),
+    DialogWindow(parent),
     ui(new Ui::CartwheelWindow)
 {
     ui->setupUi(this);
@@ -19,8 +19,7 @@ CartwheelWindow::CartwheelWindow(QWidget *parent, Player* player) :
     setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
-    m_CanClose = true;
-    m_Loop = NULL;
+    SetCanClose(true);
     m_Won = 0;
     m_Value = 0;
     m_Player = player;
@@ -46,24 +45,6 @@ CartwheelWindow::~CartwheelWindow()
     delete ui;
 }
 
-void CartwheelWindow::exec()
-{
-    m_Loop = new QEventLoop(this);
-    show();
-    m_Loop->exec();
-}
-
-void CartwheelWindow::closeEvent(QCloseEvent* event)
-{
-    if (m_CanClose){
-        if (m_Loop)
-            m_Loop->quit();
-        event->accept();
-    }else{
-        event->ignore();
-    }
-}
-
 void CartwheelWindow::RandomSlot(int random)
 {
     Evaluate(random);
@@ -115,7 +96,7 @@ void CartwheelWindow::Evaluate(int random)
         ui->lblMessage->setText(QString("%1! You won %2 Gold Crowns").arg(random).arg(won));
 
     m_Player->SetGoldCrowns(m_Player->GetGoldCrowns() + won - lost);
-    m_CanClose = true;
+    SetCanClose(true);
 }
 
 void CartwheelWindow::BetMinusSlot()
@@ -155,7 +136,7 @@ void CartwheelWindow::PlusSlot()
 }
 
 void CartwheelWindow::PlaySlot(){
-    m_CanClose = false;
+    SetCanClose(false);
     EnableButtons(false);
     ui->lblMessage->clear();
 
