@@ -4,7 +4,7 @@
 #include "commonstatic.h"
 
 PortholesWindow::PortholesWindow(QWidget *parent, Player* player) :
-    QMainWindow(parent),
+    DialogWindow(parent),
     ui(new Ui::PortholesWindow)
 {
     ui->setupUi(this);
@@ -19,8 +19,7 @@ PortholesWindow::PortholesWindow(QWidget *parent, Player* player) :
     setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
-    m_CanClose = true;
-    m_Loop = NULL;
+    SetCanClose(true);
     m_Player = player;
 
     m_RandomPicker1 = new RandomNumberPicker(this, ui->lblDice1, false);
@@ -40,24 +39,6 @@ PortholesWindow::~PortholesWindow()
     delete ui;
 }
 
-void PortholesWindow::exec()
-{
-    m_Loop = new QEventLoop(this);
-    show();
-    m_Loop->exec();
-}
-
-void PortholesWindow::closeEvent(QCloseEvent* event)
-{
-    if (m_CanClose){
-        if (m_Loop)
-            m_Loop->quit();
-        event->accept();
-    }else{
-        event->ignore();
-    }
-}
-
 void PortholesWindow::RandomSlot(int random)
 {
     if(sender()->objectName() == "1")
@@ -118,7 +99,7 @@ void PortholesWindow::Play(int player)
 
 void PortholesWindow::PlaySlot()
 {
-    m_CanClose = false;
+    SetCanClose(false);
     ui->lblMessage->clear();
     ui->lblPlayer1->setText("-");
     ui->lblPlayer2->setText("-");
@@ -149,5 +130,5 @@ void PortholesWindow::Evaluate()
     }
 
     UpdateData();
-    m_CanClose = true;
+    SetCanClose(true);
 }
