@@ -3,6 +3,7 @@
 
 #include <QMainWindow>
 #include <QEventLoop>
+#include "controls/dialogwindow.h"
 #include "core/player.h"
 #include "randomnumberpicker.h"
 
@@ -10,7 +11,7 @@ namespace Ui {
     class PlayerCreationWindow;
 }
 
-class PlayerCreationWindow : public QMainWindow
+class PlayerCreationWindow : public DialogWindow
 {
     Q_OBJECT
 
@@ -18,12 +19,8 @@ public:
     explicit PlayerCreationWindow(QWidget *parent = 0);
     ~PlayerCreationWindow();
 
-    void exec();
     Player* GetPlayer();
 
-protected:
-    void closeEvent(QCloseEvent *event);
-
 private:
     enum Random{
         RandomSkill,
@@ -39,7 +36,6 @@ private:
     int m_RandomWeaponskill;
     int m_Random;
     RandomNumberPicker* m_RandomPicker;
-    QEventLoop* m_Loop;
     Player* m_Player;
     void PickRandomNumber();
 
