@@ -4,13 +4,14 @@
 #include <QMainWindow>
 #include <QEventLoop>
 #include <QMessageBox>
+#include "controls/dialogwindow.h"
 #include "core/player.h"
 
 namespace Ui {
     class ShopWindow;
 }
 
-class ShopWindow : public QMainWindow
+class ShopWindow : public DialogWindow
 {
     Q_OBJECT
 
@@ -18,15 +19,9 @@ public:
     explicit ShopWindow(QWidget *parent = 0, Player* player=0, Section* section=0);
     ~ShopWindow();
 
-    void exec();
-
-protected:
-    void closeEvent(QCloseEvent* event);
-
 private:
     Ui::ShopWindow *ui;
 
-    QEventLoop* m_Loop;
     Player* m_Player;
     Section* m_Section;
 
