@@ -5,13 +5,14 @@
 #include <QEventLoop>
 #include <QMessageBox>
 #include <QScriptEngine>
+#include "controls/dialogwindow.h"
 #include "core/player.h"
 
 namespace Ui {
     class StatusWindow;
 }
 
-class StatusWindow : public QMainWindow
+class StatusWindow : public DialogWindow
 {
     Q_OBJECT
 
@@ -19,13 +20,8 @@ public:
     explicit StatusWindow(QWidget *parent = 0, Player* player=0, Section* section=0, QScriptEngine* engine=0, QScriptValue* functions=0);
     ~StatusWindow();
 
-    void exec();
-
     QList<Item*> UsedItems() { return m_UsedItems; }
 
-protected:
-    void closeEvent(QCloseEvent *event);
-
 private:
     Ui::StatusWindow *ui;
 
@@ -33,13 +29,13 @@ private:
     QScriptEngine* m_Engine;
     QScriptValue* m_Functions;
     QList<Item*> m_UsedItems;
-    QEventLoop* m_Loop;
     Book* m_Book;
     Section* m_Section;
     Player* m_Player;
 
     void ShowData();
     bool EquipWeapon(Weapon* weapon);
+    bool EquipArmor(Armor* armor);
     bool DropWeapon(Weapon* weapon);
     bool DropItem(Item* item);
     void ClearLayout(QLayout* layout);
@@ -55,6 +51,8 @@ private slots:
     void UseItemSlot();
     void TakeGoldCrownsSlot();
     void DiscipleLinkSlot(QString link);
+    void CombatSkillLinkSlot(QString link);
+    void EditNotesSlot();
 };
 
 #endif // STATUSWINDOW_H
